#include sf_cua.hdr
#include cuacolor.hdr
#include string.hdr
#include io.hdr
#include pick.hdr

vardef extern
  byte __color_std, __color_enhcd
enddef

procedure force_main
  vardef
    int  cnt
    long plist
  enddef
  clear
  wait "After each screen change, press any key to continue..."

  *\ Initialize CUA functions
  sf_cua_font()
  sf_cua_palette()
  cursor_off()

  *\ Clear the background
  sf_cua_background( &CUA_BACK_CYAN )

  *\ Draw a back window
  sf_cua_back_window( 02, 10, 22, 68, &CUA_BWHITE_ON_CYAN,;
                      "This is a BACK WINDOW", &BLUE_WHITE, .f. )
  get_key()

  *\ Draw a back window with browse
  sf_cua_back_window( 02, 10, 22, 68, &CUA_BWHITE_ON_CYAN,;
                      "This is a BACK WINDOW with BROWSE",;
                      &BLUE_WHITE, .t. )
  get_key()

  *\ Explode an out tile to the screen
  sf_win_explode( 02, 10, 22, 69, 112, 2000 )
  sf_out_tile( 02, 10, 22, 69, .f. )

  *\ Place text, the ^ characters will display in the second color
  *\ and the normal characters will display in the first color
  sf_cua_text_line( "This is an ^O^U^T ^T^I^L^E...",;
                    04, 30, &WHITE_BLACK, &WHITE_LIGHT_CYAN, 0 )
  get_key()

  *\ Recess a tile
  sf_in_tile( 03, 12, 07, 67, .f. )
  sf_cua_text_line( "This is an ^I^N ^T^I^L^E inside an ^O^U^T ^T^I^L^E window...",;
                    05, 17, &WHITE_BLACK, &WHITE_LIGHT_CYAN, 0 )
  get_key()
  __color_std = &WHITE_BLACK
  @ 09, 14 ?? "  The next two windows utilize a TRUE SHADOW in which"
  @ 10, 14 ?? "the color covered by the shadow is darkened rather"
  @ 11, 14 ?? "simply changing to color value 007..."
  get_key()

  *\ Draw an over window
  sf_cua_over_window( 03, 40, 22, 70, &CUA_BWHITE,;
                      "This is an OVER WINDOW",;
                      &BLUE_WHITE, .f., .f. )
  get_key()

  *\ Draw an over window with browse
  sf_cua_over_window( 01, 05, 23, 45, &CUA_BWHITE,;
                      "This is an OVER WINDOW with BROWSE",;
                      &BLUE_WHITE, .t., .f. )
  get_key()
  __color_std = &LIGHT_WHITE_BLACK
  @ 03, 07 ?? "  To best show the TRUE SHADOW we"
  @ 04, 07 ?? "now TRUE SHADOW the entire screen!"
  get_key()

  *\ True shadow the entire screen line by line...
  for cnt = 0 to 24
    sf_set_true_shadow( cnt, 0, 80 )
  next
  get_key()
  sf_cua_background( &CUA_BACK_CYAN )

  *\ Ask for an answer...
  if sf_cua_validate( "Sf_Cua_Validate()",;
                      "Select OK to run the SF_CUA_PICK_LIST() function;" +;
                      "or select CANCEL to skip it... note the button;" +;
                      "for OK/CANCEL when you select...;",;
                      &CUA_WHITE, 25000 ) = &VALID_OK
    plist = pick_init()
    for cnt = 0 to 100
      pick_add( plist, trim( i_str( cnt ) ) +;
                replicate( "0", 10 - len( trim( i_str( cnt ) ) ) ) )
    next

    *\ Display the pick list in CUA
    cnt = sf_cua_pick_list( plist, 05, 05, 21, 30, .f., .f., &CUA_WHITE,;
                            "Sf_Cua_Pick_List()", &BLUE_WHITE, 1 )
    if cnt > 0

      *\ Display the selection...
      sf_cua_over_window( 10, 40, 15, 68, &CUA_BWHITE,;
                          "Selection!", &BLUE_WHITE, .f., .f. )
      __color_std = &LIGHT_WHITE_BLACK
      @ 13, 42 ?? "You selected: " + pick_str( plist, cnt )
      get_key()
    endif
    pick_clear( plist )
  endif
  sf_cua_background( &CUA_BACK_CYAN )

  *\ Progress demonstration
  sf_cua_over_window( 02, 05, 21, 74, &CUA_WHITE, "Progress/Slide...",;
                      &BLUE_WHITE, .f., .f. )
  sf_out_tile( 08, 13, 12, 67, .t. )
  for cnt = 0 to 5000
    sf_cua_progress_h( 5000, cnt, 10, 15, 50, &YELLOW_BLACK, &CUA_WHITE )
  next
  sf_out_tile( 04, 20, 19, 25, .t. )
  for cnt = 0 to 1500
    sf_cua_progress_v( 1500, cnt, 18, 22, 13, &YELLOW_BLACK, &BLACK_YELLOW,;
                       &CUA_WHITE )
  next

  *\ Slide selection
  sf_out_tile( 15, 12, 17, 68, .t. )
  sf_cua_text_line( "            <- This is the current value, use <- -> to move, enter to end.",;
                    24, 0, &BLUE_WHITE, &BLUE_LIGHT_BLUE, 80 )
  sf_horizontal_slide( 15, 65, 16, 250, 0, 100, 1, 112,;
                       -16, .t., 24, 05, 6, &BLUE_WHITE )
  sf_out_tile( 04, 40, 19, 46, .t. )
  sf_cua_text_line( "            <- This is the current value, up/down arrows to move, enter to end.",;
                    24, 0, &BLUE_WHITE, &BLUE_LIGHT_BLUE, 80 )
  sf_vertical_slide( 05, 18, 43, 250, 0, 100, 1, 112, -16, .t.,;
                     24, 5, 5, &BLUE_WHITE )

  *\ Registration
  sf_cua_background( &CUA_BACK_CYAN )
  sf_cua_over_window( 02, 05, 21, 74, &CUA_BWHITE, "Registration",;
                      &BLUE_WHITE, .f., .f. )
  __color_std = &LIGHT_WHITE_BLACK
  @ 04, 07 ?? "                  SPECIAL FORCES REGISTRATION                     "
  @ 05, 07 ?? "                                                                  "
  @ 06, 07 ?? "    This free version of the Special Forces Library is yours to   "
  @ 07, 07 ?? "use in your programming.  It may not be sold or disassembled or   "
  @ 08, 07 ?? "in any way subjected to infringements of the copyright listed in  "
  @ 09, 07 ?? "the SF_CUA.DOC file.  This is an UNREGISTERED VERSION!!  If you   "
  @ 10, 07 ?? "choose to register, you will receive a copy without the copyright "
  @ 11, 07 ?? "line which appears when calling SF_CUA_FONT(), documentation and  "
  @ 12, 07 ?? "upgrades as they become available. ( Currently version 2.0 is     "
  @ 13, 07 ?? "planned for July/August )                                         "
  @ 14, 07 ?? "                                                                  "
  @ 15, 07 ?? "   To register send $50.00 payable to   MARK N. WITTEN            "
  @ 16, 07 ?? "                                        404 DOVE COURT            "
  @ 17, 07 ?? "                                        MT. HOLLY NJ 08060        "
  @ 18, 07 ?? "                                                                  "
  @ 19, 07 ?? "   Be sure to specify 3 1/2 or 5 1/4 size diskettes.  Enjoy...    "
  get_key()
  __color_std   = 007
  __color_enhcd = 112
  clear
  cursor_on()
  sf_standard_font()
  sf_standard_palette()
endpro
